@@ -57,11 +57,11 @@ App::Dochazka::REST - Dochazka REST server
 
 =head1 VERSION
 
-Version 0.087
+Version 0.088
 
 =cut
 
-our $VERSION = '0.087';
+our $VERSION = '0.088';
 
 
 =head2 Development status
@@ -408,38 +408,90 @@ Once the hardware is ready, the Dochazka REST software and all its
 dependencies are installed on it.  This could be accomplished by
 downloading and unpacking the tarball (or running C<git clone>) and
 following the installation instructions, or, more expediently, by
-installing a packaged version of Dochazka REST if one is available.
+installing a packaged version of Dochazka REST if one is available
+(see
+L<https://build.opensuse.org/package/show/home:smithfarm/perl-App-Dochazka-REST>).
 
 =item * B<PostgreSQL setup> -- 
 One of Dochazka REST's principal dependencies is PostgreSQL server (version
-9.2 or higher). This needs to be installed and most likely also enabled to
-start automatically at boot.
+9.2 or higher). This needs to be installed (should happen automatically
+when using the packaged version of L<App::Dochazka::REST>). Steps to enable
+it:
+
+    # chkconfig postgresql on
+    #  systemctl start postgresql.service
+    # su - postgres
+    $ psql postgres
+    postgres-# ALTER ROLE postgres WITH PASSWORD 'mypass';
+    ALTER ROLE
+
+At this point, we exit C<psql> and, still as the user C<postgres>, we 
+edit C<pg_hba.conf>. Using our favorite editor, we change the METHOD entry
+for C<local> so it looks like this:
+
+    # TYPE  DATABASE   USER   ADDRESS     METHOD
+    local   all        all                password
+
+Then, as root, we restart the postgresql service:
+
+    # systemctl restart postgresql.service
 
 =item * B<Site configuration> -- 
-Before the Dochazka REST service can be started, the site administrator
-will need to go over the core configuration defaults in
-F<Dochazka_Config.pm> and prepare the site configuration,
-F<Dochazka_SiteConfig.pm>, which will contain just those parameters that
-need to be different from the defaults.
+Before the Dochazka REST database can be initialized, we will need to
+tell L<App::Dochazka::REST> about the PostgreSQL superuser password
+that we set in the previous step. First, create a sitedir:
+
+    # mkdir /etc/dochazka
+
+And a file therein:
+
+    # cat << EOF > /etc/dochazka/Dochazka_SiteConfig.pm
+    set( 'DBINIT_CONNECT_AUTH', 'mypass' );
+    EOF
+    #
+
+(NOTE: Strictly speaking, this sitedir setup is only needed for database
+initialization. During normal operation, L<App::Dochazka::REST> connects
+to the database using the default user C<dochazka> and password
+C<dochazka>. These are taken from the site parameters C<DOCHAZKA_DBUSER>
+and C<DOCHAZKA_DBPASS>.)
 
 =item * B<Syslog setup> -- 
 It is much easier to administer a Dochazka instance if C<syslog> is running
 and configured properly to place Dochazka's log messages into a separate
-file in a known location. Dochazka REST provides a C<syslog_test> script to
-help the administrator complete this step.
+file in a known location. In the future, L<App::Dochazka::REST> might
+provide a C<syslog_test> script to help the administrator complete this
+step.
 
-=item * B<Database initialization> -- 
-Once F<Dochazka_SiteConfig.pm> is ready, the administrator executes the
-database initialization script as the PostgreSQL superuser, C<postgres>.
-The script will send log messages to C<syslog> so these can be analyzed in
-case the script generates an error.
+=item * Database initialization -- 
+In the future, there might be a nifty C<dochazka-dbinit> script to make
+this process less painful, but for now the easiest way to initialize the
+database is to clone the git repo from SourceForge and run the test suite:
 
-=item * B<Service start> -- 
-The last step is to start the Dochazka REST service using a command like
-C<systemctl start dochazka.service> and, if desired, enable the service
-to start automatically at boot. An examination of the C<syslog> messages
-generated by Dochazka REST will tell whether the service has started
-properly.
+    # cd ~/src
+    # git clone git://git.code.sf.net/p/dochazka/code dochazka
+    ...
+    # cd dochazka
+    # perl Build.PL
+    # ./Build test
+
+Assuming the previous steps were completed correctly, all the tests should
+complete without errors.
+
+=item * Service start -- 
+The last step is to start the Dochazka REST service. Maybe, in the future,
+this will be possible using a command like C<systemctl start dochazka.service>.
+Right now, though, an executable is run, as root, manually from the bash prompt:
+
+    # dochazka-rest --host [HOST] --port 80 --access-log /var/log/dochazka-rest.log
+
+or, as any user:
+
+    $ dochazka-rest
+
+=item * Take it for a spin
+Point your browser to the hostname you entered in the previous step, or to
+L<http://0:5000/> if you didn't enter a hostname.
 
 =back
 
